<?php
namespace Modules\Relatorios\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Report\ReportService;

class Gql01100QualificacaoFornecedorAtendidoRegiaoController extends \Zeedhi\Framework\Controller\Report
{
    protected $birtStrategy;
    protected $newCode;
    protected $environment;
    protected $connection;
    protected $stNomeRel;
    protected $stExtensao;
    
    public function __construct(reportService $reportService, $birtStrategy, $newCode, $environment, $connection) 
    {
        parent::__construct($reportService);
        $this->birtStrategy       = $birtStrategy;
        $this->newCode           = $newCode;
        $this->connection        = $connection;
        $this->environment       = $environment;
    }
    
    protected $reportMapping = array ();
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) 
    {
        $row = $request->getRow();
        $row['NRORG'] = $this->environment->getNrOrg();
        if($row['STRATEGY'] == 'BIRT'){
            if($row['FORNECEDOR'] != 'T'){
                 $nrlistaForn= $this->criarListaValores($row['FORNECEDOR']);
                 $row['FORNECEDOR'] = "_NRLISTA=".$nrlistaForn;
            }
            if($row['REGIAO'] != 'T'){
                $nrlistaForn = $this->criarListaValores($row['REGIAO']);
                $row['REGIAO'] = "_NRLISTA=".$nrlistaForn;
            }
            if($row['QUALIFICACAO'] != 'T'){
                $nrlistaForn = $this->criarListaValores($row['QUALIFICACAO']);
                $row['QUALIFICACAO'] = "_NRLISTA=".$nrlistaForn;
            }
            if($row['SITUACAO'] != 'T'){
                $nrlistaForn = $this->criarListaValores($row['SITUACAO']);
                $row['SITUACAO'] = "_NRLISTA=".$nrlistaForn;
            }

        }
        
        $this->birtStrategy->setReportFormat($row['QR2TYPE']);
        $this->stNomeRel = $this->getReportName($row);
        $this->reportMapping[$this->stNomeRel] =
        array (
            'strategy' => $row["STRATEGY"],
            'parameterMapping' => 
            array (
                'FORNECEDOR'         => 'P_CDFORNECED',
                'SITUACAO'           => 'P_IDSITUCADA',
                'QUALIFICACAO'       => 'P_CDQUALIF',
                'REGIAO'             => 'P_CDREGIAO',
                'NRORG'              => 'P_NRORG'
            ),
        );
    }
    
    protected function criarListaValores($lista){
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
        $valores = explode('_',$lista);
        try{
            foreach($valores as $key){
                $this->insertLista($nrlista, $key);
            }
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
     }

     public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );

        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
     }
}